/*
   Class for setting a Splits MIDI channel

   Concept, Design and Implementation by: Craig A. Lindley
   Last Update: 04/20/2022
*/

#ifndef CHANNEL_SELECTOR_H
#define CHANNEL_SELECTOR_H

class ChannelSelector {

  public:

    ChannelSelector() {}

    void init(int _splitNumber, Controls _controls, DisplayManager _dm) {

      // Save incoming
      splitNumber = _splitNumber;
      controls = _controls;
      dm = _dm;

      encoderValue = 0;

      dm.eraseInfoAreaFromLine(4);
      dm.drawCenteredText("MIDI Channel", 4, 2, ST77XX_GREEN);
    }

    boolean run() {

      // Rotate through the 16 MIDI channels
      if (controls.readEncoder(&encoderValue, 1, 1, 16)) {
        dm.eraseInfoAreaFromLine(5);

        // Format and displaym channel number
        sprintf(textBuffer, "Channel: %d", (int) encoderValue);
        dm.drawCenteredText(textBuffer, 6, 2, ST77XX_GREEN);
      }

      // Has a menu item been selected ?
      if (controls.encoderButtonSingleClicked()) {

        // Set channel on split
        splits[splitNumber].channel = (byte) encoderValue;

        dm.eraseInfoAreaFromLine(4);

        return true;
      }
      return false;
    }

  protected:

    int splitNumber;
    Controls controls;
    DisplayManager dm;
    int32_t encoderValue;

    char textBuffer[30];
};

#endif
