/*
   Class for setting a Splits MIDI key shift

   Concept, Design and Implementation by: Craig A. Lindley
   Last Update: 04/20/2022
*/

#ifndef KEYSHIFT_SELECTOR_H
#define KEYSHIFT_SELECTOR_H

class KeyShiftSelector {

  public:

    KeyShiftSelector() {}

    void init(int _splitNumber, Controls _controls, DisplayManager _dm) {

      // Save incoming
      splitNumber = _splitNumber;
      controls = _controls;
      dm = _dm;

      encoderValue = 0;

      dm.eraseInfoAreaFromLine(4);
      dm.drawCenteredText("Key Shift", 4, 2, ST77XX_GREEN);
    }

    boolean run() {

      // Rotate through the keyboard shift values -2, -1, 0, +1, +2
      if (controls.readEncoder(&encoderValue, 1, -2, +2)) {
        dm.eraseInfoAreaFromLine(5);

        // Format and display key offset number
        sprintf(textBuffer, "Key Shift: %d", (int) encoderValue);
        dm.drawCenteredText(textBuffer, 6, 2, ST77XX_GREEN);
      }

      // Has a item been selected ?
      if (controls.encoderButtonSingleClicked()) {

        // Set key shift on split 0
        splits[splitNumber].keyboardShift = (byte) encoderValue;

        dm.eraseInfoAreaFromLine(4);

        return true;
      }
      return false;
    }

  protected:

    int splitNumber;
    Controls controls;
    DisplayManager dm;
    int32_t encoderValue;

    char textBuffer[30];
};

#endif
