/*
   Pot.h - Class for encapulation of potentiometer data for use
   in HMSynth keyboard.

   Concept, Design and Implementation by: Craig A. Lindley
   Last Update: 04/20/2022
*/

#ifndef POT_H
#define POT_H

class Pot {

  public:
    // Class Constructor
    Pot(int _analogPin, int _deltaThreshold) {

      analogPin = _analogPin;
      deltaThreshold = _deltaThreshold;

      prevValue = 0;
    }

    // Determine if the pot has been rotated
    // Return true is so; otherwise return false
    boolean isActive(void) {
      value = analogRead(analogPin);
      if (abs(value - prevValue) > deltaThreshold) {
        prevValue = value;
        return true;
      } else {
        return false;
      }
    }

    // Get the current pot value
    // If returnRaw true return values in range 0..1023.
    // If returnRaw false convert value to MIDI range 0..127
    uint16_t getValue(boolean returnRaw) {

      if (returnRaw) {
        return value;
      } else {
        return map(value, 0, 1023, 0, 127);
      }
    }

  private:
    byte analogPin;
    uint16_t value;
    uint16_t prevValue;
    uint16_t deltaThreshold;
};

#endif
