/*
   Class for setting a Splits MIDI velocity

   Concept, Design and Implementation by: Craig A. Lindley
   Last Update: 04/20/2022
*/

#ifndef VELOCITY_SELECTOR_H
#define VELOCITY_SELECTOR_H

class VelocitySelector {

  public:

    VelocitySelector() {}

    void init(int _splitNumber, Controls _controls, DisplayManager _dm) {

      // Save incoming
      splitNumber = _splitNumber;
      controls = _controls;
      dm = _dm;

      encoderValue = 0;

      dm.eraseInfoAreaFromLine(4);
      dm.drawCenteredText("MIDI Velocity", 4, 2, ST77XX_GREEN);
    }

    boolean run() {

      // Rotate through the MIDI velocity values 1 .. 127
      if (controls.readEncoder(&encoderValue, 1, 1, 127)) {
        dm.eraseInfoAreaFromLine(5);

        // Format and displaym channel number
        sprintf(textBuffer, "Velocity: %d", (int) encoderValue);
        dm.drawCenteredText(textBuffer, 6, 2, ST77XX_GREEN);
      }

      // Has a menu item been selected ?
      if (controls.encoderButtonSingleClicked()) {

        // Set velocity on split
        splits[splitNumber].velocity = (byte) encoderValue;

        dm.eraseInfoAreaFromLine(4);

        return true;
      }
      return false;
    }

  protected:

    int splitNumber;
    Controls controls;
    DisplayManager dm;
    int32_t encoderValue;

    char textBuffer[30];
};

#endif
